@@ -14,7 +14,7 @@ import aiohttp
 from aiohttp import ContentTypeError, FormData
 from pyrate_limiter import BucketFullException, Duration, Limiter, Rate
 
-from roborock.containers import HomeData, HomeDataRoom, HomeDataScene, ProductResponse, RRiot, UserData
+from roborock.data import HomeData, HomeDataRoom, HomeDataScene, ProductResponse, RRiot, UserData
 from roborock.exceptions import (
     RoborockAccountDoesNotExist,
     RoborockException,
@@ -96,12 +96,15 @@ class RoborockApiClient:
                         )
                     else:
                         raise RoborockException(f"{response.get('msg')} - response code: {response_code}")
-                if response["data"]["countrycode"] is not None:
+                country_code = response["data"]["countrycode"]
+                country = response["data"]["country"]
+                if country_code is not None or country is not None:
                     self._iot_login_info = IotLoginInfo(
                         base_url=response["data"]["url"],
-                        country=response["data"]["country"],
-                        country_code=response["data"]["countrycode"],
+                        country=country,
+                        country_code=country_code,
                     )
+                    _LOGGER.debug("Country determined to be %s and code is %s", country, country_code)
                     return self._iot_login_info
             raise RoborockNoResponseFromBaseURL(
                 "No account was found for any base url we tried. Either your email is incorrect or we do not have a"
@@ -231,6 +234,9 @@ class RoborockApiClient:
 
     async def request_code_v4(self) -> None:
         """Request a code using the v4 endpoint."""
+        if await self.country_code is None or await self.country is None:
+            _LOGGER.info("No country code or country found, trying old version of request code.")
+            return await self.request_code()
         try:
             self._login_limiter.try_acquire("login")
         except BucketFullException as ex:
@@ -301,6 +307,9 @@ class RoborockApiClient:
             country = await self.country
         if country_code is None:
             country_code = await self.country_code
+        if country_code is None or country is None:
+            _LOGGER.info("No country code or country found, trying old version of code login.")
+            return await self.code_login(code)
         header_clientid = self._get_header_client_id()
         x_mercy_ks = "".join(secrets.choice(string.ascii_letters + string.digits) for _ in range(16))
         x_mercy_k = await self._sign_key_v3(x_mercy_ks)
